@@ -1,5 +1,5 @@
 package App::Provision::Mysql;
-$App::Provision::Mysql::VERSION = '0.02';
+$App::Provision::Mysql::VERSION = '0.03';
 BEGIN {
   $App::Provision::Mysql::AUTHORITY = 'cpan:GENE';
 }
@@ -7,13 +7,14 @@ use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
-sub mysql
+sub meet
 {
     my $self = shift;
     if ( $self->{system} eq 'osx' )
     {
         $self->recipe(
           [qw( brew install mysql )],
+          [ 'unset TMPDIR && mysql_install_db --verbose --user=`whoami` --basedir="$(brew --prefix mysql)" --datadir=/usr/local/var/mysql --tmpdir=/tmp' ],
         );
     }
     elsif ( $self->{system} eq 'apt' )
@@ -38,7 +39,7 @@ App::Provision::Mysql
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
